<?php
/**
 * @file
 * Responsive Tables Filter plugin file.
 */

namespace Drupal\responsive_tables_filter\Plugin\Filter;

use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;
use \DOMDocument;

/**
 * @Filter(
 *   id = "filter_responsive_tables_filter",
 *   title = @Translation("Responsive Tables Filter"),
 *   description = @Translation("Make tables in WYSIWYG fields responsive."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_MARKUP_LANGUAGE,
 * )
 */
class FilterResponsiveTablesFilter extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    if ($text != '') {
      libxml_use_internal_errors(TRUE);
      $existing = FALSE;
      $dom = new DOMDocument();
      $dom->loadHTML(mb_convert_encoding($text, 'HTML-ENTITIES', 'UTF-8'));
      $tables = $dom->getElementsByTagName('table');
      // Find all tables in text.
      //$existing = $tables->DOMNodeList;
      if (!empty($tables)) {
        foreach ($tables as $table) {
          // Find existing class attributes, if any, and append tablesaw class.
          $existing_classes = $table->getAttribute('class');
          $new_classes = !empty($existing_classes) ? $existing_classes . ' tablesaw tablesaw-stack' : 'tablesaw tablesaw-stack';
          $table->setAttribute('class', $new_classes);

          // Force data-tablesaw-mode attribute to be "stack".
          $table->setAttribute('data-tablesaw-mode', 'stack');
          $existing = TRUE;
        }
        $text = $dom->saveHTML();
        $result = new FilterProcessResult($text);
        if ($existing) {
          $result->setAttachments(array(
            'library' => array('responsive_tables_filter/tablesaw-filter'),
          ));
        }
        return $result;
      }
    }
  }
}
